pub struct ShutdownCoordinator { /* private fields */ }Expand description
A shutdown coordinator for triggering, and optionally waiting for, tasks to shut down.
Callers register a ShutdownHandle, which can be awaited to observe shutdown being triggered, or checked
synchronously via ShutdownHandle::is_triggered. When a handle is dropped, it reports completion back to the
coordinator; this is what allows shutdown_and_wait to block until every outstanding
handle has finished.
Shutdown is triggered either fire-and-forget, via shutdown, or blocking, via
shutdown_and_wait.
Shutdown on drop
Shutdown is also triggered implicitly on drop if it hasn’t already been triggered, to enforce that shutdown always happens even in exceptional circumstances. Shutdown on drop is fire-and-forget: when the coordinator’s drop logic has executed, there is no guarantee that all outstanding handles have also been dropped.
Implementations
Sourceimpl ShutdownCoordinator
impl ShutdownCoordinator
Sourcepub fn register(&mut self) -> ShutdownHandle ⓘ
pub fn register(&mut self) -> ShutdownHandle ⓘ
Registers and returns a new shutdown handle.
Sourcepub fn shutdown(self)
pub fn shutdown(self)
Signals shutdown to all outstanding handles without waiting.
When it is desirable to wait until all outstanding handles have completed (been dropped), use
shutdown_and_wait.
Sourcepub async fn shutdown_and_wait(self)
pub async fn shutdown_and_wait(self)
Signals shutdown to all outstanding handles, waiting until all handles have completed (been dropped).
If there are no outstanding handles, this returns immediately.